@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
@@ -23,4 +21,3 @@ Cross-validation in MRIQC
     cv/experiments
 
 """
-from __future__ import print_function, division, absolute_import, unicode_literals
