@@ -246,7 +246,7 @@ class nipype(_Config):
     """Estimation in GB of the RAM this workflow can allocate at any given time."""
     nprocs = os.cpu_count()
     """Number of processes (compute tasks) that can be run in parallel (multiprocessing only)."""
-    omp_nthreads = os.cpu_count()
+    omp_nthreads = int(os.getenv('OMP_NUM_THREADS', os.cpu_count()))
     """Number of CPUs a single process can access for multithreaded execution."""
     plugin = "MultiProc"
     """NiPype's execution plugin."""
@@ -432,10 +432,6 @@ class workflow(_Config):
     """Turn on FFT based spike detector (slow)."""
     headmask = "BET"
     """Use FSL BET in :py:func:`~mriqc.workflows.anatomical.headmsk_wf`."""
-    hmc_afni = True
-    """Use AFNI 3dvolreg for head motion correction (HMC) - default."""
-    hmc_fsl = False
-    """Use FSL MCFLIRT instead of AFNI for head motion correction (HMC)."""
     ica = False
     """Run ICA on the raw data and include the components in the individual reports."""
     inputs = None
