@@ -1,14 +1,6 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-#
-# @Author: oesteban
-# @Date:   2016-01-05 17:15:12
-# @Email:  code@oscaresteban.es
-# @Last modified by:   oesteban
 """Helper functions for the workflows"""
-from __future__ import print_function, division, absolute_import, unicode_literals
 from distutils.version import StrictVersion
 from builtins import range
 
@@ -30,8 +22,11 @@ def fmri_getidx(in_file, start_idx, stop_idx):
     if start_idx is None or not isdefined(start_idx) or start_idx < 0 or start_idx > max_idx:
         start_idx = 0
 
-    if (stop_idx is None or not isdefined(stop_idx) or stop_idx < start_idx or
-            stop_idx > max_idx):
+    if (
+        stop_idx is None
+        or not isdefined(stop_idx)
+        or max_idx < stop_idx < start_idx
+    ):
         stop_idx = max_idx
     return start_idx, stop_idx
 
@@ -60,7 +55,7 @@ def thresh_image(in_file, thres=0.5, out_file=None):
     data[data < thres] = 0
     data[data > 0] = 1
     nb.Nifti1Image(
-        data, im.get_affine(), im.get_header()).to_filename(out_file)
+        data, im.affine, im.header).to_filename(out_file)
     return out_file
 
 
